pub struct SubscriptionsListResponse {
pub items: Option<Vec<Subscription>>,
pub kind: Option<String>,
}Expand description
A list of Subscriptions. This is the response from the server to GET requests on the subscription collection.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list subscriptions (response)
Fields
items: Option<Vec<Subscription>>The list of subscriptions.
kind: Option<String>The type of resource. This is always mirror#subscriptionsList.